NeXosim I/O utilities
This crate contains I/O related utilities and models for NeXosim-based simulations.
At the moment this crate contains one module, port, that implements I/O thread
guard used for communication with the external world.
Documentation
The API documentation is relatively exhaustive and includes a practical overview which should provide all necessary information to get started.
Examples of usage can be found in examples directory and serial port
model.
See also NeXosim documentation.
Usage
To use the latest version, add to your Cargo.toml:
[dependencies]
nexosim-io-utils = "0.2.0"License
This software is licensed under the Apache License, Version 2.0 or the MIT license, at your option.
Contribution
Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the Apache-2.0 license, shall be dual licensed as above, without any additional terms or conditions.